Queue type for inter-process communication (IPC).
Structs
- Queues
- A struct for sending and receiving items by using very simple routing. This allows for us to send messages to a specific receiver, to any receiver, or all receivers. Automatically wraps items with the identifier of the sender so that a response can be sent back to the corresponding receiver.
- Tracked
Item - Waker
Enums
- Error
- Errors that can occur when constructing
Queues.